@@ -56,12 +56,20 @@ class Kfzcheck(object):
     searchparameter = optionen.searchparameter
     
     count_rows = 0
-    kfzcheck_dir = '/opt/kfzcheck'
-    kfzcheck_ini = 'kfzcheck.ini' # configuration file for the country selection
     bl_image = {} # list with the created pixbuf images
+    kfzcheck_dir = '/opt/kfzcheck'
+    kfzcheck_ini = os.path.expanduser('~/.kfzcheck.ini') # configuration file for the country selection
 
     Config = ConfigParser.ConfigParser()
-    Config.read(('%s/%s') % (kfzcheck_dir, kfzcheck_ini))
+
+    if os.path.isfile(kfzcheck_ini) == False: # when the ini file not exists create it in ~./.kfzcheck.ini
+        ini_file = open(kfzcheck_ini, 'w') # open the file and create it when not exists
+        Config.add_section('Country')
+        Config.set('Country', 'firstload', 'de') # first standard load is the german file
+        Config.write(ini_file)
+        ini_file.close
+        
+    Config.read(kfzcheck_ini)
     firstload = Config.get('Country', 'firstload') # load the country that specified in the configuration file
 
     def load(self, kfzlist):
@@ -210,8 +218,9 @@ class Kfzcheck(object):
         self.entry.connect('changed', self.search, self.entry, self.button_country.get_value()) # when changed load the correct csv file
         self.search(entry = '', country = self.button_country.get_value()) # show the whole list
         self.Config.set('Country', 'firstload', self.button_country.get_value()) # set the config file to the last selected country
-        ini_file = open('%s/%s' % (self.kfzcheck_dir, self.kfzcheck_ini), 'w') # open the file
+        ini_file = open(self.kfzcheck_ini, 'w') # open the file
         self.Config.write(ini_file) # write and save it
+        ini_file.close # close the ini file
         self.entry.set_text('') # set the entry field to nothing when the country field changed
         self.top.set_active(True) # set the Top filter button active (because we are at the top)
 
